#!/usr/bin/env node

/**
 * This is an example to invoke rview server
 */
'use strict'

const rview = require('rview')
const co = require('co')
const http = require('http')

co(function * () {
  let server = http.createServer()

  // Setup server for remote view
  rview({
    // Define Views
    'user': {
      profile: co.wrap(function * userProfile () {
        return `
<!DOCTYPE html><html><!-- ... --></html>
`
      }),
      $before (moduleName, methodName, url) {
        let { state } = this
        return co(function * () {
          if (state.somethingIsWrong) {
            throw new Error('Something wrong!') // Throw error to reject invoking
          }
        })
      },
      $after (moduleName, methodName, url) {
        let { state } = this
        /* ... */
      }
    },
    // URL Prefix
    $pathname: '/ui',
    // URLs to exports
    $urls: {
      'user#profile': '/mypage'
    },
    // Static directories to serve
    $statics: [
      'assets/public',
      'public'
    ],
    // Koa middlewares
    $middlewares: [
      co.wrap(function * customMW (ctx, next) {
        // Called before handling
        /* ... */
        yield next()
      })
    ],
    // Compile response body
    $compile (body) {
      /* ... */
      return body
    }
  }).applyTo(server) // Apply to existing http server
  server.listen(3000)
}).catch((err) => console.error(err))
