/**
 * Test case for rview.
 * Runs with mocha.
 */
'use strict'

const RView = require('../lib/rview.js')
const assert = require('assert')
const co = require('co')
const aport = require('aport')
const arequest = require('arequest')

describe('rview', function () {
  this.timeout(3000)
  let server, port
  let request = arequest.create({ jar: true })
  before(() => co(function * () {
    server = new RView({
      user: {
        profile () {
          return '<html><body>This is profile page</body></html>'
        }
      },
      $pathname: '/ui',
      $statics: [
        `${__dirname}/../misc/mocks/mock-public`
      ],
      $compile (src) {
        return `<!DOCTYPE html>${src}`
      }
    })
    port = yield aport()
    yield server.listen(port)
  }))

  after(() => co(function * () {
    yield server.close()
  }))

  it('Rview', () => co(function * () {
    {
      let { statusCode, headers } = yield request({
        method: 'head',
        url: `http://localhost:${port}/ui`
      })
      assert.equal(statusCode, 204)
    }
    {
      let { statusCode, body } = yield request({
        url: `http://localhost:${port}/ui/user/profile`,
        method: 'GET'
      })
      assert.equal(statusCode, 200)
      assert.equal(body, '<!DOCTYPE html><html><body>This is profile page</body></html>')
    }
    {
      let { statusCode, body } = yield request({
        method: 'GET',
        url: `http://localhost:${port}/ui/css/foo.css`
      })
      assert.equal(statusCode, 200)
      assert.ok(body)
    }
  }))
})

/* global describe, before, after, it */
